measuretools.comment_measures_in_container_with_measure_numbers
===============================================================

.. autofunction:: abjad.tools.measuretools.comment_measures_in_container_with_measure_numbers.comment_measures_in_container_with_measure_numbers
